import {
  select,
  geoPath,
  geoNaturalEarth1,
  zoom,
  event
} from 'd3';
import { getData } from './data';

// Init Topographic Projection
const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

// Get the SVG from the DOM
const svg = select('svg');
// Add a Group
const g = svg.append('g');
// Add zoom to the SVG
svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

// Render Function
const render = data => {

  // Deconstruct Data
  const  [topoJSONData, countryData] = data;
   
  // Add the Sphere
  g.append('path')
  	.attr('d', pathGenerator({type: 'Sphere'}))
  	.attr('class', 'ocean');

  // Add the Countries
  g.selectAll('path')
  	.data(topoJSONData.features)
			.enter().append('path')
  		.attr('class', 'land')
  		.attr('d', pathGenerator)
  	.append('title')
  		.text(d => countryData[d.id]);
};

getData()
  .then(data => {
  	// Render when the data is loaded
   	render(data);
});